@@ -45,8 +45,7 @@ class DoctrineDataCollector extends DataCollector
     /**
      * Adds the stack logger for a connection.
      *
-     * @param string     $name
-     * @param DebugStack $logger
+     * @param string $name
      */
     public function addLogger($name, DebugStack $logger)
     {
@@ -120,7 +119,7 @@ class DoctrineDataCollector extends DataCollector
         return 'db';
     }
 
-    private function sanitizeQueries($connectionName, $queries)
+    private function sanitizeQueries(string $connectionName, array $queries)
     {
         foreach ($queries as $i => $query) {
             $queries[$i] = $this->sanitizeQuery($connectionName, $query);
@@ -129,7 +128,7 @@ class DoctrineDataCollector extends DataCollector
         return $queries;
     }
 
-    private function sanitizeQuery($connectionName, $query)
+    private function sanitizeQuery(string $connectionName, $query)
     {
         $query['explainable'] = true;
         if (null === $query['params']) {
@@ -138,6 +137,9 @@ class DoctrineDataCollector extends DataCollector
         if (!\is_array($query['params'])) {
             $query['params'] = [$query['params']];
         }
+        if (!\is_array($query['types'])) {
+            $query['types'] = [];
+        }
         foreach ($query['params'] as $j => $param) {
             if (isset($query['types'][$j])) {
                 // Transform the param according to the type
@@ -173,19 +175,15 @@ class DoctrineDataCollector extends DataCollector
      * The return value is an array with the sanitized value and a boolean
      * indicating if the original value was kept (allowing to use the sanitized
      * value to explain the query).
-     *
-     * @param mixed $var
-     *
-     * @return array
      */
-    private function sanitizeParam($var)
+    private function sanitizeParam($var): array
     {
         if (\is_object($var)) {
             $className = \get_class($var);
 
             return method_exists($var, '__toString') ?
-                [sprintf('Object(%s): "%s"', $className, $var->__toString()), false] :
-                [sprintf('Object(%s)', $className), false];
+                [sprintf('/* Object(%s): */"%s"', $className, $var->__toString()), false] :
+                [sprintf('/* Object(%s) */', $className), false];
         }
 
         if (\is_array($var)) {
@@ -201,7 +199,7 @@ class DoctrineDataCollector extends DataCollector
         }
 
         if (\is_resource($var)) {
-            return [sprintf('Resource(%s)', get_resource_type($var)), false];
+            return [sprintf('/* Resource(%s) */', get_resource_type($var)), false];
         }
 
         return [$var, true];
