@@ -28,10 +28,10 @@ class LintCommandTest extends TestCase
         $tester = $this->createCommandTester();
         $filename = $this->createFile('{{ foo }}');
 
-        $ret = $tester->execute(array('filename' => array($filename)), array('verbosity' => OutputInterface::VERBOSITY_VERBOSE, 'decorated' => false));
+        $ret = $tester->execute(['filename' => [$filename]], ['verbosity' => OutputInterface::VERBOSITY_VERBOSE, 'decorated' => false]);
 
         $this->assertEquals(0, $ret, 'Returns 0 in case of success');
-        $this->assertContains('OK in', trim($tester->getDisplay()));
+        $this->assertStringContainsString('OK in', trim($tester->getDisplay()));
     }
 
     public function testLintIncorrectFile()
@@ -39,22 +39,20 @@ class LintCommandTest extends TestCase
         $tester = $this->createCommandTester();
         $filename = $this->createFile('{{ foo');
 
-        $ret = $tester->execute(array('filename' => array($filename)), array('decorated' => false));
+        $ret = $tester->execute(['filename' => [$filename]], ['decorated' => false]);
 
         $this->assertEquals(1, $ret, 'Returns 1 in case of error');
         $this->assertRegExp('/ERROR  in \S+ \(line /', trim($tester->getDisplay()));
     }
 
-    /**
-     * @expectedException \RuntimeException
-     */
     public function testLintFileNotReadable()
     {
+        $this->expectException('RuntimeException');
         $tester = $this->createCommandTester();
         $filename = $this->createFile('');
         unlink($filename);
 
-        $ret = $tester->execute(array('filename' => array($filename)), array('decorated' => false));
+        $ret = $tester->execute(['filename' => [$filename]], ['decorated' => false]);
     }
 
     public function testLintFileCompileTimeException()
@@ -62,30 +60,12 @@ class LintCommandTest extends TestCase
         $tester = $this->createCommandTester();
         $filename = $this->createFile("{{ 2|number_format(2, decimal_point='.', ',') }}");
 
-        $ret = $tester->execute(array('filename' => array($filename)), array('decorated' => false));
+        $ret = $tester->execute(['filename' => [$filename]], ['decorated' => false]);
 
         $this->assertEquals(1, $ret, 'Returns 1 in case of error');
         $this->assertRegExp('/ERROR  in \S+ \(line /', trim($tester->getDisplay()));
     }
 
-    /**
-     * @group legacy
-     * @expectedDeprecation Passing a command name as the first argument of "Symfony\Bridge\Twig\Command\LintCommand::__construct()" is deprecated since Symfony 3.4 and support for it will be removed in 4.0. If the command was registered by convention, make it a service instead.
-     * @expectedException \RuntimeException
-     * @expectedExceptionMessage The Twig environment needs to be set.
-     */
-    public function testLegacyLintCommand()
-    {
-        $command = new LintCommand();
-
-        $application = new Application();
-        $application->add($command);
-        $command = $application->find('lint:twig');
-
-        $tester = new CommandTester($command);
-        $tester->execute(array());
-    }
-
     /**
      * @return CommandTester
      */
@@ -113,12 +93,12 @@ class LintCommandTest extends TestCase
         return $filename;
     }
 
-    protected function setUp()
+    protected function setUp(): void
     {
-        $this->files = array();
+        $this->files = [];
     }
 
-    protected function tearDown()
+    protected function tearDown(): void
     {
         foreach ($this->files as $file) {
             if (file_exists($file)) {
