@@ -27,25 +27,22 @@ class CacheClearCommandTest extends TestCase
     private $kernel;
     /** @var Filesystem */
     private $fs;
-    private $rootDir;
 
-    protected function setUp()
+    protected function setUp(): void
     {
         $this->fs = new Filesystem();
         $this->kernel = new TestAppKernel('test', true);
-        $this->rootDir = sys_get_temp_dir().\DIRECTORY_SEPARATOR.uniqid('sf2_cache_', true);
-        $this->kernel->setRootDir($this->rootDir);
-        $this->fs->mkdir($this->rootDir);
+        $this->fs->mkdir($this->kernel->getProjectDir());
     }
 
-    protected function tearDown()
+    protected function tearDown(): void
     {
-        $this->fs->remove($this->rootDir);
+        $this->fs->remove($this->kernel->getProjectDir());
     }
 
     public function testCacheIsFreshAfterCacheClearedWithWarmup()
     {
-        $input = new ArrayInput(array('cache:clear'));
+        $input = new ArrayInput(['cache:clear']);
         $application = new Application($this->kernel);
         $application->setCatchExceptions(false);
 
@@ -54,7 +51,7 @@ class CacheClearCommandTest extends TestCase
         // Ensure that all *.meta files are fresh
         $finder = new Finder();
         $metaFiles = $finder->files()->in($this->kernel->getCacheDir())->name('*.php.meta');
-        // simply check that cache is warmed up
+        // check that cache is warmed up
         $this->assertNotEmpty($metaFiles);
         $configCacheFactory = new ConfigCacheFactory(true);
 
@@ -82,9 +79,6 @@ class CacheClearCommandTest extends TestCase
         }
         $this->assertTrue($found, 'Kernel file should present as resource');
 
-        if (\defined('HHVM_VERSION')) {
-            return;
-        }
         $containerRef = new \ReflectionClass(require $containerFile);
         $containerFile = str_replace('tes_'.\DIRECTORY_SEPARATOR, 'test'.\DIRECTORY_SEPARATOR, $containerRef->getFileName());
         $this->assertRegExp(sprintf('/\'kernel.container_class\'\s*=>\s*\'%s\'/', $containerClass), file_get_contents($containerFile), 'kernel.container_class is properly set on the dumped container');
