@@ -14,19 +14,19 @@ namespace Symfony\Bundle\FrameworkBundle\Tests\Functional;
 /**
  * Checks that the container compiles correctly when all the bundle features are enabled.
  */
-class ContainerDumpTest extends WebTestCase
+class ContainerDumpTest extends AbstractWebTestCase
 {
     public function testContainerCompilationInDebug()
     {
         $client = $this->createClient(['test_case' => 'ContainerDump', 'root_config' => 'config.yml']);
 
-        $this->assertTrue($client->getContainer()->has('serializer'));
+        $this->assertTrue(static::$container->has('serializer'));
     }
 
     public function testContainerCompilation()
     {
         $client = $this->createClient(['test_case' => 'ContainerDump', 'root_config' => 'config.yml', 'debug' => false]);
 
-        $this->assertTrue($client->getContainer()->has('serializer'));
+        $this->assertTrue(static::$container->has('serializer'));
     }
 }
