@@ -32,11 +32,9 @@ class MainConfigurationTest extends TestCase
         ],
     ];
 
-    /**
-     * @expectedException \Symfony\Component\Config\Definition\Exception\InvalidConfigurationException
-     */
     public function testNoConfigForProvider()
     {
+        $this->expectException('Symfony\Component\Config\Definition\Exception\InvalidConfigurationException');
         $config = [
             'providers' => [
                 'stub' => [],
@@ -48,11 +46,9 @@ class MainConfigurationTest extends TestCase
         $processor->processConfiguration($configuration, [$config]);
     }
 
-    /**
-     * @expectedException \Symfony\Component\Config\Definition\Exception\InvalidConfigurationException
-     */
     public function testManyConfigForProvider()
     {
+        $this->expectException('Symfony\Component\Config\Definition\Exception\InvalidConfigurationException');
         $config = [
             'providers' => [
                 'stub' => [
