@@ -98,12 +98,12 @@ class EnvVarProcessorTest extends TestCase
     }
 
     /**
-     * @expectedException \Symfony\Component\DependencyInjection\Exception\RuntimeException
-     * @expectedExceptionMessage Non-numeric env var
      * @dataProvider invalidInts
      */
     public function testGetEnvIntInvalid($value)
     {
+        $this->expectException('Symfony\Component\DependencyInjection\Exception\RuntimeException');
+        $this->expectExceptionMessage('Non-numeric env var');
         $processor = new EnvVarProcessor(new Container());
 
         $processor->getEnv('int', 'foo', function ($name) use ($value) {
@@ -148,12 +148,12 @@ class EnvVarProcessorTest extends TestCase
     }
 
     /**
-     * @expectedException \Symfony\Component\DependencyInjection\Exception\RuntimeException
-     * @expectedExceptionMessage Non-numeric env var
      * @dataProvider invalidFloats
      */
     public function testGetEnvFloatInvalid($value)
     {
+        $this->expectException('Symfony\Component\DependencyInjection\Exception\RuntimeException');
+        $this->expectExceptionMessage('Non-numeric env var');
         $processor = new EnvVarProcessor(new Container());
 
         $processor->getEnv('float', 'foo', function ($name) use ($value) {
@@ -197,12 +197,12 @@ class EnvVarProcessorTest extends TestCase
     }
 
     /**
-     * @expectedException \Symfony\Component\DependencyInjection\Exception\RuntimeException
-     * @expectedExceptionMessage undefined constant
      * @dataProvider invalidConsts
      */
     public function testGetEnvConstInvalid($value)
     {
+        $this->expectException('Symfony\Component\DependencyInjection\Exception\RuntimeException');
+        $this->expectExceptionMessage('undefined constant');
         $processor = new EnvVarProcessor(new Container());
 
         $processor->getEnv('const', 'foo', function ($name) use ($value) {
@@ -233,25 +233,48 @@ class EnvVarProcessorTest extends TestCase
         $this->assertSame('hello', $result);
     }
 
-    public function testGetEnvJson()
+    public function testGetEnvTrim()
     {
         $processor = new EnvVarProcessor(new Container());
 
-        $result = $processor->getEnv('json', 'foo', function ($name) {
+        $result = $processor->getEnv('trim', 'foo', function ($name) {
             $this->assertSame('foo', $name);
 
-            return json_encode([1]);
+            return " hello\n";
         });
 
-        $this->assertSame([1], $result);
+        $this->assertSame('hello', $result);
     }
 
     /**
-     * @expectedException \Symfony\Component\DependencyInjection\Exception\RuntimeException
-     * @expectedExceptionMessage Syntax error
+     * @dataProvider validJson
      */
+    public function testGetEnvJson($value, $processed)
+    {
+        $processor = new EnvVarProcessor(new Container());
+
+        $result = $processor->getEnv('json', 'foo', function ($name) use ($value) {
+            $this->assertSame('foo', $name);
+
+            return $value;
+        });
+
+        $this->assertSame($processed, $result);
+    }
+
+    public function validJson()
+    {
+        return [
+            ['[1]', [1]],
+            ['{"key": "value"}', ['key' => 'value']],
+            [null, null],
+        ];
+    }
+
     public function testGetEnvInvalidJson()
     {
+        $this->expectException('Symfony\Component\DependencyInjection\Exception\RuntimeException');
+        $this->expectExceptionMessage('Syntax error');
         $processor = new EnvVarProcessor(new Container());
 
         $processor->getEnv('json', 'foo', function ($name) {
@@ -262,12 +285,12 @@ class EnvVarProcessorTest extends TestCase
     }
 
     /**
-     * @expectedException \Symfony\Component\DependencyInjection\Exception\RuntimeException
-     * @expectedExceptionMessage Invalid JSON env var
      * @dataProvider otherJsonValues
      */
     public function testGetEnvJsonOther($value)
     {
+        $this->expectException('Symfony\Component\DependencyInjection\Exception\RuntimeException');
+        $this->expectExceptionMessage('Invalid JSON env var');
         $processor = new EnvVarProcessor(new Container());
 
         $processor->getEnv('json', 'foo', function ($name) use ($value) {
@@ -284,15 +307,14 @@ class EnvVarProcessorTest extends TestCase
             [1.1],
             [true],
             [false],
+            ['foo'],
         ];
     }
 
-    /**
-     * @expectedException \Symfony\Component\DependencyInjection\Exception\RuntimeException
-     * @expectedExceptionMessage Unsupported env var prefix
-     */
     public function testGetEnvUnknown()
     {
+        $this->expectException('Symfony\Component\DependencyInjection\Exception\RuntimeException');
+        $this->expectExceptionMessage('Unsupported env var prefix');
         $processor = new EnvVarProcessor(new Container());
 
         $processor->getEnv('unknown', 'foo', function ($name) {
@@ -301,4 +323,159 @@ class EnvVarProcessorTest extends TestCase
             return 'foo';
         });
     }
+
+    public function testGetEnvKeyInvalidKey()
+    {
+        $this->expectException('Symfony\Component\DependencyInjection\Exception\RuntimeException');
+        $this->expectExceptionMessage('Invalid env "key:foo": a key specifier should be provided.');
+        $processor = new EnvVarProcessor(new Container());
+
+        $processor->getEnv('key', 'foo', function ($name) {
+            $this->fail('Should not get here');
+        });
+    }
+
+    /**
+     * @dataProvider noArrayValues
+     */
+    public function testGetEnvKeyNoArrayResult($value)
+    {
+        $this->expectException('Symfony\Component\DependencyInjection\Exception\RuntimeException');
+        $this->expectExceptionMessage('Resolved value of "foo" did not result in an array value.');
+        $processor = new EnvVarProcessor(new Container());
+
+        $processor->getEnv('key', 'index:foo', function ($name) use ($value) {
+            $this->assertSame('foo', $name);
+
+            return $value;
+        });
+    }
+
+    public function noArrayValues()
+    {
+        return [
+            [null],
+            ['string'],
+            [1],
+            [true],
+        ];
+    }
+
+    /**
+     * @dataProvider invalidArrayValues
+     */
+    public function testGetEnvKeyArrayKeyNotFound($value)
+    {
+        $this->expectException('Symfony\Component\DependencyInjection\Exception\EnvNotFoundException');
+        $this->expectExceptionMessage('Key "index" not found in');
+        $processor = new EnvVarProcessor(new Container());
+
+        $processor->getEnv('key', 'index:foo', function ($name) use ($value) {
+            $this->assertSame('foo', $name);
+
+            return $value;
+        });
+    }
+
+    public function invalidArrayValues()
+    {
+        return [
+            [[]],
+            [['index2' => 'value']],
+            [['index', 'index2']],
+        ];
+    }
+
+    /**
+     * @dataProvider arrayValues
+     */
+    public function testGetEnvKey($value)
+    {
+        $processor = new EnvVarProcessor(new Container());
+
+        $this->assertSame($value['index'], $processor->getEnv('key', 'index:foo', function ($name) use ($value) {
+            $this->assertSame('foo', $name);
+
+            return $value;
+        }));
+    }
+
+    public function arrayValues()
+    {
+        return [
+            [['index' => 'password']],
+            [['index' => 'true']],
+            [['index' => false]],
+            [['index' => '1']],
+            [['index' => 1]],
+            [['index' => '1.1']],
+            [['index' => 1.1]],
+            [['index' => []]],
+            [['index' => ['val1', 'val2']]],
+        ];
+    }
+
+    public function testGetEnvKeyChained()
+    {
+        $processor = new EnvVarProcessor(new Container());
+
+        $this->assertSame('password', $processor->getEnv('key', 'index:file:foo', function ($name) {
+            $this->assertSame('file:foo', $name);
+
+            return [
+                'index' => 'password',
+            ];
+        }));
+    }
+
+    /**
+     * @dataProvider validNullables
+     */
+    public function testGetEnvNullable($value, $processed)
+    {
+        $processor = new EnvVarProcessor(new Container());
+        $result = $processor->getEnv('default', ':foo', function ($name) use ($value) {
+            $this->assertSame('foo', $name);
+
+            return $value;
+        });
+        $this->assertSame($processed, $result);
+    }
+
+    public function validNullables()
+    {
+        return [
+            ['hello', 'hello'],
+            ['', null],
+            ['null', 'null'],
+            ['Null', 'Null'],
+            ['NULL', 'NULL'],
+         ];
+    }
+
+    public function testRequireMissingFile()
+    {
+        $this->expectException('Symfony\Component\DependencyInjection\Exception\EnvNotFoundException');
+        $this->expectExceptionMessage('missing-file');
+        $processor = new EnvVarProcessor(new Container());
+
+        $processor->getEnv('require', '/missing-file', function ($name) {
+            return $name;
+        });
+    }
+
+    public function testRequireFile()
+    {
+        $path = __DIR__.'/Fixtures/php/return_foo_string.php';
+
+        $processor = new EnvVarProcessor(new Container());
+
+        $result = $processor->getEnv('require', $path, function ($name) use ($path) {
+            $this->assertSame($path, $name);
+
+            return $path;
+        });
+
+        $this->assertEquals('foo', $result);
+    }
 }
