@@ -22,7 +22,7 @@ class DotenvTest extends TestCase
      */
     public function testParseWithFormatError($data, $error)
     {
-        $dotenv = new Dotenv();
+        $dotenv = new Dotenv(true);
 
         try {
             $dotenv->parse($data);
@@ -40,8 +40,14 @@ class DotenvTest extends TestCase
             ['FOO', "Missing = in the environment variable declaration in \".env\" at line 1.\n...FOO...\n     ^ line 1 offset 3"],
             ['FOO="foo', "Missing quote to end the value in \".env\" at line 1.\n...FOO=\"foo...\n          ^ line 1 offset 8"],
             ['FOO=\'foo', "Missing quote to end the value in \".env\" at line 1.\n...FOO='foo...\n          ^ line 1 offset 8"],
+            ['FOO=\'foo'."\n", "Missing quote to end the value in \".env\" at line 1.\n...FOO='foo\\n...\n          ^ line 1 offset 8"],
             ['export FOO', "Unable to unset an environment variable in \".env\" at line 1.\n...export FOO...\n            ^ line 1 offset 10"],
             ['FOO=${FOO', "Unclosed braces on variable expansion in \".env\" at line 1.\n...FOO=\${FOO...\n           ^ line 1 offset 9"],
+            ['FOO= BAR', "Whitespace are not supported before the value in \".env\" at line 1.\n...FOO= BAR...\n      ^ line 1 offset 4"],
+            ['Стасян', "Invalid character in variable name in \".env\" at line 1.\n...Стасян...\n  ^ line 1 offset 0"],
+            ['FOO!', "Missing = in the environment variable declaration in \".env\" at line 1.\n...FOO!...\n     ^ line 1 offset 3"],
+            ['FOO=$(echo foo', "Missing closing parenthesis. in \".env\" at line 1.\n...FOO=$(echo foo...\n                ^ line 1 offset 14"],
+            ['FOO=$(echo foo'."\n", "Missing closing parenthesis. in \".env\" at line 1.\n...FOO=$(echo foo\\n...\n                ^ line 1 offset 14"],
         ];
 
         if ('\\' !== \DIRECTORY_SEPARATOR) {
@@ -56,7 +62,7 @@ class DotenvTest extends TestCase
      */
     public function testParse($data, $expected)
     {
-        $dotenv = new Dotenv();
+        $dotenv = new Dotenv(true);
         $this->assertSame($expected, $dotenv->parse($data));
     }
 
@@ -64,6 +70,7 @@ class DotenvTest extends TestCase
     {
         putenv('LOCAL=local');
         $_ENV['REMOTE'] = 'remote';
+        $_SERVER['SERVERVAR'] = 'servervar';
 
         $tests = [
             // backslashes
@@ -150,6 +157,7 @@ class DotenvTest extends TestCase
             ['FOO=" $ "', ['FOO' => ' $ ']],
             ['BAR=$LOCAL', ['BAR' => 'local']],
             ['BAR=$REMOTE', ['BAR' => 'remote']],
+            ['BAR=$SERVERVAR', ['BAR' => 'servervar']],
             ['FOO=$NOTDEFINED', ['FOO' => '']],
         ];
 
@@ -185,7 +193,104 @@ class DotenvTest extends TestCase
         file_put_contents($path1, 'FOO=BAR');
         file_put_contents($path2, 'BAR=BAZ');
 
-        (new Dotenv())->load($path1, $path2);
+        (new Dotenv(true))->load($path1, $path2);
+
+        $foo = getenv('FOO');
+        $bar = getenv('BAR');
+
+        putenv('FOO');
+        putenv('BAR');
+        unlink($path1);
+        unlink($path2);
+        rmdir($tmpdir);
+
+        $this->assertSame('BAR', $foo);
+        $this->assertSame('BAZ', $bar);
+    }
+
+    public function testLoadEnv()
+    {
+        unset($_ENV['FOO']);
+        unset($_ENV['BAR']);
+        unset($_SERVER['FOO']);
+        unset($_SERVER['BAR']);
+        putenv('FOO');
+        putenv('BAR');
+
+        @mkdir($tmpdir = sys_get_temp_dir().'/dotenv');
+
+        $path = tempnam($tmpdir, 'sf-');
+
+        // .env
+
+        file_put_contents($path, 'FOO=BAR');
+        (new Dotenv(true))->loadEnv($path, 'TEST_APP_ENV');
+        $this->assertSame('BAR', getenv('FOO'));
+        $this->assertSame('dev', getenv('TEST_APP_ENV'));
+
+        // .env.local
+
+        $_SERVER['TEST_APP_ENV'] = 'local';
+        file_put_contents("$path.local", 'FOO=localBAR');
+        (new Dotenv(true))->loadEnv($path, 'TEST_APP_ENV');
+        $this->assertSame('localBAR', getenv('FOO'));
+
+        // special case for test
+
+        $_SERVER['TEST_APP_ENV'] = 'test';
+        (new Dotenv(true))->loadEnv($path, 'TEST_APP_ENV');
+        $this->assertSame('BAR', getenv('FOO'));
+
+        // .env.dev
+
+        unset($_SERVER['TEST_APP_ENV']);
+        file_put_contents("$path.dev", 'FOO=devBAR');
+        (new Dotenv(true))->loadEnv($path, 'TEST_APP_ENV');
+        $this->assertSame('devBAR', getenv('FOO'));
+
+        // .env.dev.local
+
+        file_put_contents("$path.dev.local", 'FOO=devlocalBAR');
+        (new Dotenv(true))->loadEnv($path, 'TEST_APP_ENV');
+        $this->assertSame('devlocalBAR', getenv('FOO'));
+
+        // .env.dist
+
+        unlink($path);
+        file_put_contents("$path.dist", 'BAR=distBAR');
+        (new Dotenv(true))->loadEnv($path, 'TEST_APP_ENV');
+        $this->assertSame('distBAR', getenv('BAR'));
+
+        putenv('FOO');
+        putenv('BAR');
+        unlink("$path.dist");
+        unlink("$path.local");
+        unlink("$path.dev");
+        unlink("$path.dev.local");
+        rmdir($tmpdir);
+    }
+
+    public function testOverload()
+    {
+        unset($_ENV['FOO']);
+        unset($_ENV['BAR']);
+        unset($_SERVER['FOO']);
+        unset($_SERVER['BAR']);
+
+        putenv('FOO=initial_foo_value');
+        putenv('BAR=initial_bar_value');
+        $_ENV['FOO'] = 'initial_foo_value';
+        $_ENV['BAR'] = 'initial_bar_value';
+
+        @mkdir($tmpdir = sys_get_temp_dir().'/dotenv');
+
+        $path1 = tempnam($tmpdir, 'sf-');
+        $path2 = tempnam($tmpdir, 'sf-');
+
+        file_put_contents($path1, 'FOO=BAR');
+        file_put_contents($path2, 'BAR=BAZ');
+
+        (new Dotenv(true))->overload($path1, $path2);
 
         $foo = getenv('FOO');
         $bar = getenv('BAR');
@@ -200,41 +305,39 @@ class DotenvTest extends TestCase
         $this->assertSame('BAZ', $bar);
     }
 
-    /**
-     * @expectedException \Symfony\Component\Dotenv\Exception\PathException
-     */
     public function testLoadDirectory()
     {
-        $dotenv = new Dotenv();
+        $this->expectException('Symfony\Component\Dotenv\Exception\PathException');
+        $dotenv = new Dotenv(true);
         $dotenv->load(__DIR__);
     }
 
-    public function testServerSuperglobalIsNotOverriden()
+    public function testServerSuperglobalIsNotOverridden()
     {
         $originalValue = $_SERVER['argc'];
 
-        $dotenv = new Dotenv();
+        $dotenv = new Dotenv(true);
         $dotenv->populate(['argc' => 'new_value']);
 
         $this->assertSame($originalValue, $_SERVER['argc']);
     }
 
-    public function testEnvVarIsNotOverriden()
+    public function testEnvVarIsNotOverridden()
     {
         putenv('TEST_ENV_VAR=original_value');
         $_SERVER['TEST_ENV_VAR'] = 'original_value';
 
-        $dotenv = new Dotenv();
+        $dotenv = new Dotenv(true);
         $dotenv->populate(['TEST_ENV_VAR' => 'new_value']);
 
         $this->assertSame('original_value', getenv('TEST_ENV_VAR'));
     }
 
-    public function testHttpVarIsPartiallyOverriden()
+    public function testHttpVarIsPartiallyOverridden()
     {
         $_SERVER['HTTP_TEST_ENV_VAR'] = 'http_value';
 
-        $dotenv = new Dotenv();
+        $dotenv = new Dotenv(true);
         $dotenv->populate(['HTTP_TEST_ENV_VAR' => 'env_value']);
 
         $this->assertSame('env_value', getenv('HTTP_TEST_ENV_VAR'));
@@ -242,6 +345,18 @@ class DotenvTest extends TestCase
         $this->assertSame('http_value', $_SERVER['HTTP_TEST_ENV_VAR']);
     }
 
+    public function testEnvVarIsOverriden()
+    {
+        putenv('TEST_ENV_VAR_OVERRIDEN=original_value');
+
+        $dotenv = new Dotenv(true);
+        $dotenv->populate(['TEST_ENV_VAR_OVERRIDEN' => 'new_value'], true);
+
+        $this->assertSame('new_value', getenv('TEST_ENV_VAR_OVERRIDEN'));
+        $this->assertSame('new_value', $_ENV['TEST_ENV_VAR_OVERRIDEN']);
+        $this->assertSame('new_value', $_SERVER['TEST_ENV_VAR_OVERRIDEN']);
+    }
+
     public function testMemorizingLoadedVarsNamesInSpecialVar()
     {
         // Special variable not exists
@@ -256,7 +371,7 @@ class DotenvTest extends TestCase
         unset($_SERVER['DATABASE_URL']);
         putenv('DATABASE_URL');
 
-        $dotenv = new Dotenv();
+        $dotenv = new Dotenv(true);
         $dotenv->populate(['APP_DEBUG' => '1', 'DATABASE_URL' => 'mysql://root@localhost/db']);
 
         $this->assertSame('APP_DEBUG,DATABASE_URL', getenv('SYMFONY_DOTENV_VARS'));
@@ -273,7 +388,7 @@ class DotenvTest extends TestCase
         unset($_SERVER['DATABASE_URL']);
         putenv('DATABASE_URL');
 
-        $dotenv = new Dotenv();
+        $dotenv = new Dotenv(true);
         $dotenv->populate(['APP_DEBUG' => '0', 'DATABASE_URL' => 'mysql://root@localhost/db']);
         $dotenv->populate(['DATABASE_URL' => 'sqlite:///somedb.sqlite']);
 
@@ -289,7 +404,7 @@ class DotenvTest extends TestCase
         putenv('BAZ=baz');
         putenv('DOCUMENT_ROOT=/var/www');
 
-        $dotenv = new Dotenv();
+        $dotenv = new Dotenv(true);
         $dotenv->populate(['FOO' => 'foo1', 'BAR' => 'bar1', 'BAZ' => 'baz1', 'DOCUMENT_ROOT' => '/boot']);
 
         $this->assertSame('foo1', getenv('FOO'));
@@ -297,4 +412,31 @@ class DotenvTest extends TestCase
         $this->assertSame('baz1', getenv('BAZ'));
         $this->assertSame('/var/www', getenv('DOCUMENT_ROOT'));
     }
+
+    /**
+     * @group legacy
+     * @expectedDeprecation The default value of "$usePutenv" argument of "%s" will be changed from "true" to "false" in Symfony 5.0. You should define its value explicitly.
+     */
+    public function testDeprecationWarning()
+    {
+        new Dotenv();
+    }
+
+    public function testNoDeprecationWarning()
+    {
+        $dotenv = new Dotenv(true);
+        $this->assertInstanceOf(Dotenv::class, $dotenv);
+        $dotenv = new Dotenv(false);
+        $this->assertInstanceOf(Dotenv::class, $dotenv);
+    }
+
+    public function testDoNotUsePutenv()
+    {
+        $dotenv = new Dotenv(false);
+        $dotenv->populate(['TEST_USE_PUTENV' => 'no']);
+
+        $this->assertSame('no', $_SERVER['TEST_USE_PUTENV']);
+        $this->assertSame('no', $_ENV['TEST_USE_PUTENV']);
+        $this->assertFalse(getenv('TEST_USE_PUTENV'));
+    }
 }
