@@ -11,6 +11,7 @@
 
 namespace Symfony\Component\Form\Tests\Extension\DataCollector;
 
+use PHPUnit\Framework\MockObject\MockObject;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\Form\Extension\DataCollector\FormDataCollector;
 use Symfony\Component\Form\Form;
@@ -20,7 +21,7 @@ use Symfony\Component\Form\FormView;
 class FormDataCollectorTest extends TestCase
 {
     /**
-     * @var \PHPUnit_Framework_MockObject_MockObject
+     * @var MockObject
      */
     private $dataExtractor;
 
@@ -30,17 +31,17 @@ class FormDataCollectorTest extends TestCase
     private $dataCollector;
 
     /**
-     * @var \PHPUnit_Framework_MockObject_MockObject
+     * @var MockObject
      */
     private $dispatcher;
 
     /**
-     * @var \PHPUnit_Framework_MockObject_MockObject
+     * @var MockObject
      */
     private $factory;
 
     /**
-     * @var \PHPUnit_Framework_MockObject_MockObject
+     * @var MockObject
      */
     private $dataMapper;
 
@@ -64,7 +65,7 @@ class FormDataCollectorTest extends TestCase
      */
     private $childView;
 
-    protected function setUp()
+    protected function setUp(): void
     {
         $this->dataExtractor = $this->getMockBuilder('Symfony\Component\Form\Extension\DataCollector\FormDataExtractorInterface')->getMock();
         $this->dataCollector = new FormDataCollector($this->dataExtractor);
@@ -84,29 +85,29 @@ class FormDataCollectorTest extends TestCase
         $this->dataExtractor->expects($this->at(0))
             ->method('extractConfiguration')
             ->with($this->form)
-            ->will($this->returnValue(['config' => 'foo']));
+            ->willReturn(['config' => 'foo']);
         $this->dataExtractor->expects($this->at(1))
             ->method('extractConfiguration')
             ->with($this->childForm)
-            ->will($this->returnValue(['config' => 'bar']));
+            ->willReturn(['config' => 'bar']);
 
         $this->dataExtractor->expects($this->at(2))
             ->method('extractDefaultData')
             ->with($this->form)
-            ->will($this->returnValue(['default_data' => 'foo']));
+            ->willReturn(['default_data' => 'foo']);
         $this->dataExtractor->expects($this->at(3))
             ->method('extractDefaultData')
             ->with($this->childForm)
-            ->will($this->returnValue(['default_data' => 'bar']));
+            ->willReturn(['default_data' => 'bar']);
 
         $this->dataExtractor->expects($this->at(4))
             ->method('extractSubmittedData')
             ->with($this->form)
-            ->will($this->returnValue(['submitted_data' => 'foo']));
+            ->willReturn(['submitted_data' => 'foo']);
         $this->dataExtractor->expects($this->at(5))
             ->method('extractSubmittedData')
             ->with($this->childForm)
-            ->will($this->returnValue(['submitted_data' => 'bar']));
+            ->willReturn(['submitted_data' => 'bar']);
 
         $this->dataCollector->collectConfiguration($this->form);
         $this->dataCollector->collectDefaultData($this->form);
@@ -150,11 +151,11 @@ class FormDataCollectorTest extends TestCase
         $this->dataExtractor->expects($this->at(0))
             ->method('extractConfiguration')
             ->with($form1)
-            ->will($this->returnValue(['config' => 'foo']));
+            ->willReturn(['config' => 'foo']);
         $this->dataExtractor->expects($this->at(1))
             ->method('extractConfiguration')
             ->with($form2)
-            ->will($this->returnValue(['config' => 'bar']));
+            ->willReturn(['config' => 'bar']);
 
         $this->dataCollector->collectConfiguration($form1);
         $this->dataCollector->collectConfiguration($form2);
@@ -200,12 +201,12 @@ class FormDataCollectorTest extends TestCase
         $this->dataExtractor->expects($this->at(0))
             ->method('extractConfiguration')
             ->with($this->form)
-            ->will($this->returnValue(['config' => 'foo']));
+            ->willReturn(['config' => 'foo']);
 
         $this->dataExtractor->expects($this->at(1))
             ->method('extractDefaultData')
             ->with($this->form)
-            ->will($this->returnValue(['default_data' => 'foo']));
+            ->willReturn(['default_data' => 'foo']);
 
         $this->dataCollector->collectConfiguration($this->form);
         $this->dataCollector->buildPreliminaryFormTree($this->form);
@@ -272,39 +273,39 @@ class FormDataCollectorTest extends TestCase
         $this->dataExtractor->expects($this->at(0))
             ->method('extractConfiguration')
             ->with($this->form)
-            ->will($this->returnValue(['config' => 'foo']));
+            ->willReturn(['config' => 'foo']);
         $this->dataExtractor->expects($this->at(1))
             ->method('extractConfiguration')
             ->with($this->childForm)
-            ->will($this->returnValue(['config' => 'bar']));
+            ->willReturn(['config' => 'bar']);
 
         $this->dataExtractor->expects($this->at(2))
             ->method('extractDefaultData')
             ->with($this->form)
-            ->will($this->returnValue(['default_data' => 'foo']));
+            ->willReturn(['default_data' => 'foo']);
         $this->dataExtractor->expects($this->at(3))
             ->method('extractDefaultData')
             ->with($this->childForm)
-            ->will($this->returnValue(['default_data' => 'bar']));
+            ->willReturn(['default_data' => 'bar']);
 
         $this->dataExtractor->expects($this->at(4))
             ->method('extractSubmittedData')
             ->with($this->form)
-            ->will($this->returnValue(['submitted_data' => 'foo']));
+            ->willReturn(['submitted_data' => 'foo']);
         $this->dataExtractor->expects($this->at(5))
             ->method('extractSubmittedData')
             ->with($this->childForm)
-            ->will($this->returnValue(['submitted_data' => 'bar']));
+            ->willReturn(['submitted_data' => 'bar']);
 
         $this->dataExtractor->expects($this->at(6))
             ->method('extractViewVariables')
             ->with($this->view)
-            ->will($this->returnValue(['view_vars' => 'foo']));
+            ->willReturn(['view_vars' => 'foo']);
 
         $this->dataExtractor->expects($this->at(7))
             ->method('extractViewVariables')
             ->with($this->childView)
-            ->will($this->returnValue(['view_vars' => 'bar']));
+            ->willReturn(['view_vars' => 'bar']);
 
         $this->dataCollector->collectConfiguration($this->form);
         $this->dataCollector->collectDefaultData($this->form);
@@ -365,76 +366,76 @@ class FormDataCollectorTest extends TestCase
         $this->dataExtractor->expects($this->at(0))
             ->method('extractConfiguration')
             ->with($form1)
-            ->will($this->returnValue(['config' => 'foo']));
+            ->willReturn(['config' => 'foo']);
         $this->dataExtractor->expects($this->at(1))
             ->method('extractConfiguration')
             ->with($child1)
-            ->will($this->returnValue(['config' => 'bar']));
+            ->willReturn(['config' => 'bar']);
 
         $this->dataExtractor->expects($this->at(2))
             ->method('extractDefaultData')
             ->with($form1)
-            ->will($this->returnValue(['default_data' => 'foo']));
+            ->willReturn(['default_data' => 'foo']);
         $this->dataExtractor->expects($this->at(3))
             ->method('extractDefaultData')
             ->with($child1)
-            ->will($this->returnValue(['default_data' => 'bar']));
+            ->willReturn(['default_data' => 'bar']);
 
         $this->dataExtractor->expects($this->at(4))
             ->method('extractSubmittedData')
             ->with($form1)
-            ->will($this->returnValue(['submitted_data' => 'foo']));
+            ->willReturn(['submitted_data' => 'foo']);
         $this->dataExtractor->expects($this->at(5))
             ->method('extractSubmittedData')
             ->with($child1)
-            ->will($this->returnValue(['submitted_data' => 'bar']));
+            ->willReturn(['submitted_data' => 'bar']);
 
         $this->dataExtractor->expects($this->at(6))
             ->method('extractViewVariables')
             ->with($form1View)
-            ->will($this->returnValue(['view_vars' => 'foo']));
+            ->willReturn(['view_vars' => 'foo']);
 
         $this->dataExtractor->expects($this->at(7))
             ->method('extractViewVariables')
             ->with($child1View)
-            ->will($this->returnValue(['view_vars' => $child1View->vars]));
+            ->willReturn(['view_vars' => $child1View->vars]);
 
         $this->dataExtractor->expects($this->at(8))
             ->method('extractConfiguration')
             ->with($form2)
-            ->will($this->returnValue(['config' => 'foo']));
+            ->willReturn(['config' => 'foo']);
         $this->dataExtractor->expects($this->at(9))
             ->method('extractConfiguration')
             ->with($child1)
-            ->will($this->returnValue(['config' => 'bar']));
+            ->willReturn(['config' => 'bar']);
 
         $this->dataExtractor->expects($this->at(10))
             ->method('extractDefaultData')
             ->with($form2)
-            ->will($this->returnValue(['default_data' => 'foo']));
+            ->willReturn(['default_data' => 'foo']);
         $this->dataExtractor->expects($this->at(11))
             ->method('extractDefaultData')
             ->with($child1)
-            ->will($this->returnValue(['default_data' => 'bar']));
+            ->willReturn(['default_data' => 'bar']);
 
         $this->dataExtractor->expects($this->at(12))
             ->method('extractSubmittedData')
             ->with($form2)
-            ->will($this->returnValue(['submitted_data' => 'foo']));
+            ->willReturn(['submitted_data' => 'foo']);
         $this->dataExtractor->expects($this->at(13))
             ->method('extractSubmittedData')
             ->with($child1)
-            ->will($this->returnValue(['submitted_data' => 'bar']));
+            ->willReturn(['submitted_data' => 'bar']);
 
         $this->dataExtractor->expects($this->at(14))
             ->method('extractViewVariables')
             ->with($form2View)
-            ->will($this->returnValue(['view_vars' => 'foo']));
+            ->willReturn(['view_vars' => 'foo']);
 
         $this->dataExtractor->expects($this->at(15))
             ->method('extractViewVariables')
             ->with($child1View)
-            ->will($this->returnValue(['view_vars' => $child1View->vars]));
+            ->willReturn(['view_vars' => $child1View->vars]);
 
         $this->dataCollector->collectConfiguration($form1);
         $this->dataCollector->collectDefaultData($form1);
@@ -448,7 +449,7 @@ class FormDataCollectorTest extends TestCase
         $this->dataCollector->collectViewVariables($form2View);
         $this->dataCollector->buildFinalFormTree($form2, $form2View);
 
-        $this->dataCollector->serialize();
+        serialize($this->dataCollector);
     }
 
     public function testFinalFormReliesOnFormViewStructure()
@@ -518,11 +519,11 @@ class FormDataCollectorTest extends TestCase
         $this->dataExtractor->expects($this->at(0))
             ->method('extractConfiguration')
             ->with($this->form)
-            ->will($this->returnValue(['config' => 'foo']));
+            ->willReturn(['config' => 'foo']);
         $this->dataExtractor->expects($this->at(1))
             ->method('extractConfiguration')
             ->with($this->childForm)
-            ->will($this->returnValue(['config' => 'bar']));
+            ->willReturn(['config' => 'bar']);
 
         // explicitly call collectConfiguration(), since $this->childForm is not
         // contained in the form tree
@@ -566,11 +567,11 @@ class FormDataCollectorTest extends TestCase
         $this->dataExtractor->expects($this->at(0))
             ->method('extractConfiguration')
             ->with($this->form)
-            ->will($this->returnValue(['config' => 'foo']));
+            ->willReturn(['config' => 'foo']);
         $this->dataExtractor->expects($this->at(1))
             ->method('extractConfiguration')
             ->with($this->childForm)
-            ->will($this->returnValue(['config' => 'bar']));
+            ->willReturn(['config' => 'bar']);
 
         // explicitly call collectConfiguration(), since $this->childForm is not
         // contained in the form tree
@@ -611,22 +612,22 @@ class FormDataCollectorTest extends TestCase
         $form1->add($childForm1);
         $this->dataExtractor
              ->method('extractConfiguration')
-             ->will($this->returnValue([]));
+             ->willReturn([]);
         $this->dataExtractor
              ->method('extractDefaultData')
-             ->will($this->returnValue([]));
+             ->willReturn([]);
         $this->dataExtractor->expects($this->at(4))
             ->method('extractSubmittedData')
             ->with($form1)
-            ->will($this->returnValue(['errors' => ['foo']]));
+            ->willReturn(['errors' => ['foo']]);
         $this->dataExtractor->expects($this->at(5))
             ->method('extractSubmittedData')
             ->with($childForm1)
-            ->will($this->returnValue(['errors' => ['bar', 'bam']]));
+            ->willReturn(['errors' => ['bar', 'bam']]);
         $this->dataExtractor->expects($this->at(8))
             ->method('extractSubmittedData')
             ->with($form2)
-            ->will($this->returnValue(['errors' => ['baz']]));
+            ->willReturn(['errors' => ['baz']]);
 
         $this->dataCollector->collectSubmittedData($form1);
 
@@ -653,30 +654,30 @@ class FormDataCollectorTest extends TestCase
 
         $this->dataExtractor
             ->method('extractConfiguration')
-            ->will($this->returnValue([]));
+            ->willReturn([]);
         $this->dataExtractor
             ->method('extractDefaultData')
-            ->will($this->returnValue([]));
+            ->willReturn([]);
         $this->dataExtractor->expects($this->at(10))
             ->method('extractSubmittedData')
             ->with($this->form)
-            ->will($this->returnValue(['errors' => []]));
+            ->willReturn(['errors' => []]);
         $this->dataExtractor->expects($this->at(11))
             ->method('extractSubmittedData')
             ->with($child1Form)
-            ->will($this->returnValue(['errors' => []]));
+            ->willReturn(['errors' => []]);
         $this->dataExtractor->expects($this->at(12))
             ->method('extractSubmittedData')
             ->with($child11Form)
-            ->will($this->returnValue(['errors' => ['foo']]));
+            ->willReturn(['errors' => ['foo']]);
         $this->dataExtractor->expects($this->at(13))
             ->method('extractSubmittedData')
             ->with($child2Form)
-            ->will($this->returnValue(['errors' => []]));
+            ->willReturn(['errors' => []]);
         $this->dataExtractor->expects($this->at(14))
             ->method('extractSubmittedData')
             ->with($child21Form)
-            ->will($this->returnValue(['errors' => []]));
+            ->willReturn(['errors' => []]);
 
         $this->dataCollector->collectSubmittedData($this->form);
         $this->dataCollector->buildPreliminaryFormTree($this->form);
@@ -701,14 +702,14 @@ class FormDataCollectorTest extends TestCase
 
         $this->dataExtractor->expects($this->any())
             ->method('extractConfiguration')
-            ->will($this->returnValue([]));
+            ->willReturn([]);
         $this->dataExtractor->expects($this->any())
             ->method('extractDefaultData')
-            ->will($this->returnValue([]));
+            ->willReturn([]);
         $this->dataExtractor->expects($this->any())
             ->method('extractSubmittedData')
             ->with($form)
-            ->will($this->returnValue(['errors' => ['baz']]));
+            ->willReturn(['errors' => ['baz']]);
 
         $this->dataCollector->buildPreliminaryFormTree($form);
         $this->dataCollector->collectSubmittedData($form);
