@@ -11,8 +11,10 @@
 
 namespace Symfony\Component\Form\Tests;
 
+use PHPUnit\Framework\MockObject\MockObject;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\Form\FormFactory;
+use Symfony\Component\Form\FormInterface;
 use Symfony\Component\Form\FormTypeGuesserChain;
 use Symfony\Component\Form\Guess\Guess;
 use Symfony\Component\Form\Guess\TypeGuess;
@@ -24,22 +26,22 @@ use Symfony\Component\Form\Guess\ValueGuess;
 class FormFactoryTest extends TestCase
 {
     /**
-     * @var \PHPUnit_Framework_MockObject_MockObject
+     * @var MockObject
      */
     private $guesser1;
 
     /**
-     * @var \PHPUnit_Framework_MockObject_MockObject
+     * @var MockObject
      */
     private $guesser2;
 
     /**
-     * @var \PHPUnit_Framework_MockObject_MockObject
+     * @var MockObject
      */
     private $registry;
 
     /**
-     * @var \PHPUnit_Framework_MockObject_MockObject
+     * @var MockObject
      */
     private $builder;
 
@@ -48,7 +50,7 @@ class FormFactoryTest extends TestCase
      */
     private $factory;
 
-    protected function setUp()
+    protected function setUp(): void
     {
         $this->guesser1 = $this->getMockBuilder('Symfony\Component\Form\FormTypeGuesserInterface')->getMock();
         $this->guesser2 = $this->getMockBuilder('Symfony\Component\Form\FormTypeGuesserInterface')->getMock();
@@ -146,21 +148,17 @@ class FormFactoryTest extends TestCase
         $this->assertSame($this->builder, $this->factory->createNamedBuilder('name', 'type', 'DATA', $options));
     }
 
-    /**
-     * @expectedException        \Symfony\Component\Form\Exception\UnexpectedTypeException
-     * @expectedExceptionMessage Expected argument of type "string", "stdClass" given
-     */
     public function testCreateNamedBuilderThrowsUnderstandableException()
     {
+        $this->expectException('Symfony\Component\Form\Exception\UnexpectedTypeException');
+        $this->expectExceptionMessage('Expected argument of type "string", "stdClass" given');
         $this->factory->createNamedBuilder('name', new \stdClass());
     }
 
-    /**
-     * @expectedException        \Symfony\Component\Form\Exception\UnexpectedTypeException
-     * @expectedExceptionMessage Expected argument of type "string", "stdClass" given
-     */
     public function testCreateThrowsUnderstandableException()
     {
+        $this->expectException('Symfony\Component\Form\Exception\UnexpectedTypeException');
+        $this->expectExceptionMessage('Expected argument of type "string", "stdClass" given');
         $this->factory->create(new \stdClass());
     }
 
@@ -196,11 +194,13 @@ class FormFactoryTest extends TestCase
             ->method('buildForm')
             ->with($this->builder, $resolvedOptions);
 
+        $form = $this->createMock(FormInterface::class);
+
         $this->builder->expects($this->once())
             ->method('getForm')
-            ->willReturn('FORM');
+            ->willReturn($form);
 
-        $this->assertSame('FORM', $this->factory->create('TYPE', null, $options));
+        $this->assertSame($form, $this->factory->create('TYPE', null, $options));
     }
 
     public function testCreateNamed()
@@ -227,11 +227,13 @@ class FormFactoryTest extends TestCase
             ->method('buildForm')
             ->with($this->builder, $resolvedOptions);
 
+        $form = $this->createMock(FormInterface::class);
+
         $this->builder->expects($this->once())
             ->method('getForm')
-            ->willReturn('FORM');
+            ->willReturn($form);
 
-        $this->assertSame('FORM', $this->factory->createNamed('name', 'type', null, $options));
+        $this->assertSame($form, $this->factory->createNamed('name', 'type', null, $options));
     }
 
     public function testCreateBuilderForPropertyWithoutTypeGuesser()
@@ -245,11 +247,11 @@ class FormFactoryTest extends TestCase
         $factory->expects($this->once())
             ->method('createNamedBuilder')
             ->with('firstName', 'Symfony\Component\Form\Extension\Core\Type\TextType', null, [])
-            ->willReturn('builderInstance');
+            ->willReturn($this->builder);
 
         $this->builder = $factory->createBuilderForProperty('Application\Author', 'firstName');
 
-        $this->assertEquals('builderInstance', $this->builder);
+        $this->assertSame($this->builder, $this->builder);
     }
 
     public function testCreateBuilderForPropertyCreatesFormWithHighestConfidence()
@@ -277,11 +279,11 @@ class FormFactoryTest extends TestCase
         $factory->expects($this->once())
             ->method('createNamedBuilder')
             ->with('firstName', 'Symfony\Component\Form\Extension\Core\Type\PasswordType', null, ['attr' => ['maxlength' => 7]])
-            ->willReturn('builderInstance');
+            ->willReturn($this->builder);
 
         $this->builder = $factory->createBuilderForProperty('Application\Author', 'firstName');
 
-        $this->assertEquals('builderInstance', $this->builder);
+        $this->assertSame($this->builder, $this->builder);
     }
 
     public function testCreateBuilderCreatesTextFormIfNoGuess()
@@ -296,11 +298,11 @@ class FormFactoryTest extends TestCase
         $factory->expects($this->once())
             ->method('createNamedBuilder')
             ->with('firstName', 'Symfony\Component\Form\Extension\Core\Type\TextType')
-            ->willReturn('builderInstance');
+            ->willReturn($this->builder);
 
         $this->builder = $factory->createBuilderForProperty('Application\Author', 'firstName');
 
-        $this->assertEquals('builderInstance', $this->builder);
+        $this->assertSame($this->builder, $this->builder);
     }
 
     public function testOptionsCanBeOverridden()
@@ -319,7 +321,7 @@ class FormFactoryTest extends TestCase
         $factory->expects($this->once())
             ->method('createNamedBuilder')
             ->with('firstName', 'Symfony\Component\Form\Extension\Core\Type\TextType', null, ['attr' => ['class' => 'foo', 'maxlength' => 11]])
-            ->willReturn('builderInstance');
+            ->willReturn($this->builder);
 
         $this->builder = $factory->createBuilderForProperty(
             'Application\Author',
@@ -328,7 +330,7 @@ class FormFactoryTest extends TestCase
             ['attr' => ['maxlength' => 11]]
         );
 
-        $this->assertEquals('builderInstance', $this->builder);
+        $this->assertSame($this->builder, $this->builder);
     }
 
     public function testCreateBuilderUsesMaxLengthIfFound()
@@ -354,14 +356,14 @@ class FormFactoryTest extends TestCase
         $factory->expects($this->once())
             ->method('createNamedBuilder')
             ->with('firstName', 'Symfony\Component\Form\Extension\Core\Type\TextType', null, ['attr' => ['maxlength' => 20]])
-            ->willReturn('builderInstance');
+            ->willReturn($this->builder);
 
         $this->builder = $factory->createBuilderForProperty(
             'Application\Author',
             'firstName'
         );
 
-        $this->assertEquals('builderInstance', $this->builder);
+        $this->assertSame($this->builder, $this->builder);
     }
 
     public function testCreateBuilderUsesMaxLengthAndPattern()
@@ -387,7 +389,7 @@ class FormFactoryTest extends TestCase
         $factory->expects($this->once())
             ->method('createNamedBuilder')
             ->with('firstName', 'Symfony\Component\Form\Extension\Core\Type\TextType', null, ['attr' => ['maxlength' => 20, 'pattern' => '.{5,}', 'class' => 'tinymce']])
-            ->willReturn('builderInstance');
+            ->willReturn($this->builder);
 
         $this->builder = $factory->createBuilderForProperty(
             'Application\Author',
@@ -396,7 +398,7 @@ class FormFactoryTest extends TestCase
             ['attr' => ['class' => 'tinymce']]
         );
 
-        $this->assertEquals('builderInstance', $this->builder);
+        $this->assertSame($this->builder, $this->builder);
     }
 
     public function testCreateBuilderUsesRequiredSettingWithHighestConfidence()
@@ -422,14 +424,14 @@ class FormFactoryTest extends TestCase
         $factory->expects($this->once())
             ->method('createNamedBuilder')
             ->with('firstName', 'Symfony\Component\Form\Extension\Core\Type\TextType', null, ['required' => false])
-            ->willReturn('builderInstance');
+            ->willReturn($this->builder);
 
         $this->builder = $factory->createBuilderForProperty(
             'Application\Author',
             'firstName'
         );
 
-        $this->assertEquals('builderInstance', $this->builder);
+        $this->assertSame($this->builder, $this->builder);
     }
 
     public function testCreateBuilderUsesPatternIfFound()
@@ -455,14 +457,14 @@ class FormFactoryTest extends TestCase
         $factory->expects($this->once())
             ->method('createNamedBuilder')
             ->with('firstName', 'Symfony\Component\Form\Extension\Core\Type\TextType', null, ['attr' => ['pattern' => '[a-zA-Z]']])
-            ->willReturn('builderInstance');
+            ->willReturn($this->builder);
 
         $this->builder = $factory->createBuilderForProperty(
             'Application\Author',
             'firstName'
         );
 
-        $this->assertEquals('builderInstance', $this->builder);
+        $this->assertSame($this->builder, $this->builder);
     }
 
     private function getMockFactory(array $methods = [])
