@@ -32,7 +32,7 @@ class DoctrineReceiverTest extends TestCase
         $serializer = $this->createSerializer();
 
         $doctrineEnvelope = $this->createDoctrineEnvelope();
-        $connection = $this->getMockBuilder(Connection::class)->disableOriginalConstructor()->getMock();
+        $connection = $this->createMock(Connection::class);
         $connection->method('get')->willReturn($doctrineEnvelope);
 
         $receiver = new DoctrineReceiver($connection, $serializer);
@@ -53,16 +53,14 @@ class DoctrineReceiverTest extends TestCase
         $this->assertSame(1, $transportMessageIdStamp->getId());
     }
 
-    /**
-     * @expectedException \Symfony\Component\Messenger\Exception\MessageDecodingFailedException
-     */
     public function testItRejectTheMessageIfThereIsAMessageDecodingFailedException()
     {
+        $this->expectException('Symfony\Component\Messenger\Exception\MessageDecodingFailedException');
         $serializer = $this->createMock(PhpSerializer::class);
         $serializer->method('decode')->willThrowException(new MessageDecodingFailedException());
 
         $doctrineEnvelop = $this->createDoctrineEnvelope();
-        $connection = $this->getMockBuilder(Connection::class)->disableOriginalConstructor()->getMock();
+        $connection = $this->createMock(Connection::class);
         $connection->method('get')->willReturn($doctrineEnvelop);
         $connection->expects($this->once())->method('reject');
 
