@@ -14,6 +14,7 @@ namespace Symfony\Component\Security\Http\Tests\Firewall;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\Response;
+use Symfony\Component\HttpKernel\Event\RequestEvent;
 use Symfony\Component\Security\Http\Firewall\LogoutListener;
 
 class LogoutListenerTest extends TestCase
@@ -30,9 +31,9 @@ class LogoutListenerTest extends TestCase
         $httpUtils->expects($this->once())
             ->method('checkRequestPath')
             ->with($request, $options['logout_path'])
-            ->will($this->returnValue(false));
+            ->willReturn(false);
 
-        $listener->handle($event);
+        $listener($event);
     }
 
     public function testHandleMatchedPathWithSuccessHandlerAndCsrfValidation()
@@ -49,20 +50,20 @@ class LogoutListenerTest extends TestCase
         $httpUtils->expects($this->once())
             ->method('checkRequestPath')
             ->with($request, $options['logout_path'])
-            ->will($this->returnValue(true));
+            ->willReturn(true);
 
         $tokenManager->expects($this->once())
             ->method('isTokenValid')
-            ->will($this->returnValue(true));
+            ->willReturn(true);
 
         $successHandler->expects($this->once())
             ->method('onLogoutSuccess')
             ->with($request)
-            ->will($this->returnValue($response = new Response()));
+            ->willReturn($response = new Response());
 
         $tokenStorage->expects($this->once())
             ->method('getToken')
-            ->will($this->returnValue($token = $this->getToken()));
+            ->willReturn($token = $this->getToken());
 
         $handler = $this->getHandler();
         $handler->expects($this->once())
@@ -79,7 +80,7 @@ class LogoutListenerTest extends TestCase
 
         $listener->addHandler($handler);
 
-        $listener->handle($event);
+        $listener($event);
     }
 
     public function testHandleMatchedPathWithoutSuccessHandlerAndCsrfValidation()
@@ -93,16 +94,16 @@ class LogoutListenerTest extends TestCase
         $httpUtils->expects($this->once())
             ->method('checkRequestPath')
             ->with($request, $options['logout_path'])
-            ->will($this->returnValue(true));
+            ->willReturn(true);
 
         $successHandler->expects($this->once())
             ->method('onLogoutSuccess')
             ->with($request)
-            ->will($this->returnValue($response = new Response()));
+            ->willReturn($response = new Response());
 
         $tokenStorage->expects($this->once())
             ->method('getToken')
-            ->will($this->returnValue($token = $this->getToken()));
+            ->willReturn($token = $this->getToken());
 
         $handler = $this->getHandler();
         $handler->expects($this->once())
@@ -119,14 +120,15 @@ class LogoutListenerTest extends TestCase
 
         $listener->addHandler($handler);
 
-        $listener->handle($event);
+        $listener($event);
     }
 
     /**
-     * @expectedException \RuntimeException
+     * @group legacy
      */
     public function testSuccessHandlerReturnsNonResponse()
     {
+        $this->expectException('RuntimeException');
         $successHandler = $this->getSuccessHandler();
 
         list($listener, $tokenStorage, $httpUtils, $options) = $this->getListener($successHandler);
@@ -136,21 +138,19 @@ class LogoutListenerTest extends TestCase
         $httpUtils->expects($this->once())
             ->method('checkRequestPath')
             ->with($request, $options['logout_path'])
-            ->will($this->returnValue(true));
+            ->willReturn(true);
 
         $successHandler->expects($this->once())
             ->method('onLogoutSuccess')
             ->with($request)
-            ->will($this->returnValue(null));
+            ->willReturn(null);
 
-        $listener->handle($event);
+        $listener($event);
     }
 
-    /**
-     * @expectedException \Symfony\Component\Security\Core\Exception\LogoutException
-     */
     public function testCsrfValidationFails()
     {
+        $this->expectException('Symfony\Component\Security\Core\Exception\LogoutException');
         $tokenManager = $this->getTokenManager();
 
         list($listener, $tokenStorage, $httpUtils, $options) = $this->getListener(null, $tokenManager);
@@ -162,13 +162,13 @@ class LogoutListenerTest extends TestCase
         $httpUtils->expects($this->once())
             ->method('checkRequestPath')
             ->with($request, $options['logout_path'])
-            ->will($this->returnValue(true));
+            ->willReturn(true);
 
         $tokenManager->expects($this->once())
             ->method('isTokenValid')
-            ->will($this->returnValue(false));
+            ->willReturn(false);
 
-        $listener->handle($event);
+        $listener($event);
     }
 
     private function getTokenManager()
@@ -183,13 +183,13 @@ class LogoutListenerTest extends TestCase
 
     private function getGetResponseEvent()
     {
-        $event = $this->getMockBuilder('Symfony\Component\HttpKernel\Event\GetResponseEvent')
+        $event = $this->getMockBuilder(RequestEvent::class)
             ->disableOriginalConstructor()
             ->getMock();
 
         $event->expects($this->any())
             ->method('getRequest')
-            ->will($this->returnValue($request = new Request()));
+            ->willReturn($request = new Request());
 
         return [$event, $request];
     }
