@@ -47,11 +47,9 @@ class UrlValidatorTest extends ConstraintValidatorTestCase
         $this->assertNoViolation();
     }
 
-    /**
-     * @expectedException \Symfony\Component\Validator\Exception\UnexpectedTypeException
-     */
     public function testExpectsStringCompatibleType()
     {
+        $this->expectException('Symfony\Component\Validator\Exception\UnexpectedValueException');
         $this->validator->validate(new \stdClass(), new Url());
     }
 
@@ -65,6 +63,40 @@ class UrlValidatorTest extends ConstraintValidatorTestCase
         $this->assertNoViolation();
     }
 
+    /**
+     * @dataProvider getValidUrlsWithWhitespaces
+     */
+    public function testValidUrlsWithWhitespaces($url)
+    {
+        $this->validator->validate($url, new Url(['normalizer' => 'trim']));
+
+        $this->assertNoViolation();
+    }
+
+    /**
+     * @dataProvider getValidRelativeUrls
+     * @dataProvider getValidUrls
+     */
+    public function testValidRelativeUrl($url)
+    {
+        $constraint = new Url([
+            'relativeProtocol' => true,
+        ]);
+
+        $this->validator->validate($url, $constraint);
+
+        $this->assertNoViolation();
+    }
+
+    public function getValidRelativeUrls()
+    {
+        return [
+            ['//google.com'],
+            ['//symfony.fake/blog/'],
+            ['//symfony.com/search?type=&q=url+validator'],
+        ];
+    }
+
     public function getValidUrls()
     {
         return [
@@ -127,6 +159,19 @@ class UrlValidatorTest extends ConstraintValidatorTestCase
             ['http://symfony.com#fragment'],
             ['http://symfony.com/#fragment'],
             ['http://symfony.com/#one_more%20test'],
+            ['http://example.com/exploit.html?hello[0]=test'],
+        ];
+    }
+
+    public function getValidUrlsWithWhitespaces()
+    {
+        return [
+            ["\x20http://www.google.com"],
+            ["\x09\x09http://www.google.com."],
+            ["http://symfony.fake/blog/\x0A"],
+            ["http://symfony.com/search?type=&q=url+validator\x0D\x0D"],
+            ["\x00https://google.com:80\x00"],
+            ["\x0B\x0Bhttp://username:password@symfony.com\x0B\x0B"],
         ];
     }
 
@@ -147,6 +192,46 @@ class UrlValidatorTest extends ConstraintValidatorTestCase
             ->assertRaised();
     }
 
+    /**
+     * @dataProvider getInvalidRelativeUrls
+     * @dataProvider getInvalidUrls
+     */
+    public function testInvalidRelativeUrl($url)
+    {
+        $constraint = new Url([
+            'message' => 'myMessage',
+            'relativeProtocol' => true,
+        ]);
+
+        $this->validator->validate($url, $constraint);
+
+        $this->buildViolation('myMessage')
+            ->setParameter('{{ value }}', '"'.$url.'"')
+            ->setCode(Url::INVALID_URL_ERROR)
+            ->assertRaised();
+    }
+
+    public function getInvalidRelativeUrls()
+    {
+        return [
+            ['/google.com'],
+            ['//goog_le.com'],
+            ['//google.com::aa'],
+            ['//google.com:aa'],
+            ['//127.0.0.1:aa/'],
+            ['//[::1'],
+            ['//hello.☎/'],
+            ['//:password@symfony.com'],
+            ['//:password@@symfony.com'],
+            ['//username:passwordsymfony.com'],
+            ['//usern@me:password@symfony.com'],
+            ['//example.com/exploit.html?<script>alert(1);</script>'],
+            ['//example.com/exploit.html?hel lo'],
+            ['//example.com/exploit.html?not_a%hex'],
+            ['//'],
+        ];
+    }
+
     public function getInvalidUrls()
     {
         return [
@@ -200,6 +285,8 @@ class UrlValidatorTest extends ConstraintValidatorTestCase
     /**
      * @dataProvider getCheckDns
      * @requires function Symfony\Bridge\PhpUnit\DnsMock::withMockedHosts
+     * @group legacy
+     * @expectedDeprecation The "checkDNS" option in "Symfony\Component\Validator\Constraints\Url" is deprecated since Symfony 4.1. Its false-positive rate is too high to be relied upon.
      */
     public function testCheckDns($violation)
     {
@@ -230,6 +317,8 @@ class UrlValidatorTest extends ConstraintValidatorTestCase
     /**
      * @dataProvider getCheckDnsTypes
      * @requires function Symfony\Bridge\PhpUnit\DnsMock::withMockedHosts
+     * @group legacy
+     * @expectedDeprecation The "checkDNS" option in "Symfony\Component\Validator\Constraints\Url" is deprecated since Symfony 4.1. Its false-positive rate is too high to be relied upon.
      */
     public function testCheckDnsByType($type)
     {
@@ -264,28 +353,14 @@ class UrlValidatorTest extends ConstraintValidatorTestCase
     }
 
     /**
-     * @group legacy
-     */
-    public function testCheckDnsWithBoolean()
-    {
-        DnsMock::withMockedHosts(['example.com' => [['type' => 'A']]]);
-
-        $constraint = new Url([
-            'checkDNS' => true,
-            'dnsMessage' => 'myMessage',
-        ]);
-
-        $this->validator->validate('http://example.com', $constraint);
-
-        $this->assertNoViolation();
-    }
-
-    /**
-     * @expectedException \Symfony\Component\Validator\Exception\InvalidOptionsException
      * @requires function Symfony\Bridge\PhpUnit\DnsMock::withMockedHosts
+     * @group legacy
+     * @expectedDeprecation The "checkDNS" option in "Symfony\Component\Validator\Constraints\Url" is deprecated since Symfony 4.1. Its false-positive rate is too high to be relied upon.
+     * @expectedDeprecation The "dnsMessage" option in "Symfony\Component\Validator\Constraints\Url" is deprecated since Symfony 4.1.
      */
     public function testCheckDnsWithInvalidType()
     {
+        $this->expectException('Symfony\Component\Validator\Exception\InvalidOptionsException');
         DnsMock::withMockedHosts(['example.com' => [['type' => 'A']]]);
 
         $constraint = new Url([
@@ -295,6 +370,19 @@ class UrlValidatorTest extends ConstraintValidatorTestCase
 
         $this->validator->validate('http://example.com', $constraint);
     }
+
+    /**
+     * @group legacy
+     * @expectedDeprecation The "checkDNS" option in "Symfony\Component\Validator\Constraints\Url" is deprecated since Symfony 4.1. Its false-positive rate is too high to be relied upon.
+     */
+    public function testCheckDnsOptionIsDeprecated()
+    {
+        $constraint = new Url([
+            'checkDNS' => Url::CHECK_DNS_TYPE_NONE,
+        ]);
+
+        $this->validator->validate('http://example.com', $constraint);
+    }
 }
 
 class EmailProvider
