@@ -34,12 +34,10 @@ class DefinitionTest extends TestCase
         $this->assertEquals(['a', 'e'], $definition->getInitialPlaces());
     }
 
-    /**
-     * @expectedException \Symfony\Component\Workflow\Exception\LogicException
-     * @expectedExceptionMessage Place "d" cannot be the initial place as it does not exist.
-     */
     public function testSetInitialPlaceAndPlaceIsNotDefined()
     {
+        $this->expectException('Symfony\Component\Workflow\Exception\LogicException');
+        $this->expectExceptionMessage('Place "d" cannot be the initial place as it does not exist.');
         $definition = new Definition([], [], 'd');
     }
 
@@ -54,23 +52,19 @@ class DefinitionTest extends TestCase
         $this->assertSame($transition, $definition->getTransitions()[0]);
     }
 
-    /**
-     * @expectedException \Symfony\Component\Workflow\Exception\LogicException
-     * @expectedExceptionMessage Place "c" referenced in transition "name" does not exist.
-     */
     public function testAddTransitionAndFromPlaceIsNotDefined()
     {
+        $this->expectException('Symfony\Component\Workflow\Exception\LogicException');
+        $this->expectExceptionMessage('Place "c" referenced in transition "name" does not exist.');
         $places = range('a', 'b');
 
         new Definition($places, [new Transition('name', 'c', $places[1])]);
     }
 
-    /**
-     * @expectedException \Symfony\Component\Workflow\Exception\LogicException
-     * @expectedExceptionMessage Place "c" referenced in transition "name" does not exist.
-     */
     public function testAddTransitionAndToPlaceIsNotDefined()
     {
+        $this->expectException('Symfony\Component\Workflow\Exception\LogicException');
+        $this->expectExceptionMessage('Place "c" referenced in transition "name" does not exist.');
         $places = range('a', 'b');
 
         new Definition($places, [new Transition('name', $places[0], 'c')]);
